==> ballz_1.0.1.orig.tar.gz: ballz-1.0.1/src/gui/datawriter.hpp <==
/*
 * Copyright (c) 2007, Olof Naessen and Per Larsson
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *    * Redistributions of source code must retain the above copyright notice, 
 *      this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above copyright notice, 
 *      this list of conditions and the following disclaimer in the documentation 
 *      and/or other materials provided with the distribution.
 *    * Neither the name of the Darkbits nor the names of its contributors may be 
 *      used to endorse or promote products derived from this software without 
 *      specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef BALLZ_DATAWRITER_HPP
#define BALLZ_DATAWRITER_HPP

#include "guichan.hpp"
#include <allegro.h>

class DataWriter : public gcn::Widget {
public:
	DataWriter();

	void draw(gcn::Graphics *graphics);

	void setText(const std::string &text);

	const std::string &getText();

	void setLettersWritten(int lettersWritten);

	int getLettersWritten();

	bool isEverythingWritten();

    void logic();

private:
    enum Image
    {
        BALLZ,
        THEPROFESSOR,
        THECOLONEL
    };

	std::string mText;
	int mLettersWritten;
    BITMAP* mBallzImage;
    BITMAP* mTheProfessorImage;
    BITMAP* mTheColonelImage;
    Image mImage; 
    int mFrameCounter;
};

#endif

==> ballz_1.0.4.orig.tar.gz: ballz-1.0.4/src/gui/datawriter.hpp <==
/*
 * Copyright (c) 2007, Olof Naessen and Per Larsson
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *    * Redistributions of source code must retain the above copyright notice, 
 *      this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above copyright notice, 
 *      this list of conditions and the following disclaimer in the documentation 
 *      and/or other materials provided with the distribution.
 *    * Neither the name of the Darkbits nor the names of its contributors may be 
 *      used to endorse or promote products derived from this software without 
 *      specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef BALLZ_DATAWRITER_HPP
#define BALLZ_DATAWRITER_HPP

#include "guichan.hpp"
#include <allegro.h>

class DataWriter : public gcn::Widget {
public:
	DataWriter();

	void draw(gcn::Graphics *graphics);

	void setText(const std::string &text);

	const std::string &getText();

	void setLettersWritten(size_t lettersWritten);

	size_t getLettersWritten();

	bool isEverythingWritten();

    void logic();

private:
    enum Image
    {
        BALLZ,
        THEPROFESSOR,
        THECOLONEL
    };

	std::string mText;
	size_t mLettersWritten;
    BITMAP* mBallzImage;
    BITMAP* mTheProfessorImage;
    BITMAP* mTheColonelImage;
    Image mImage; 
    int mFrameCounter;
};

#endif
